import { ChangeDetectorRef, EventEmitter, InjectionToken, OnDestroy, OnInit } from '@angular/core';
import { HasInitialized } from '../core/initialized';
import { NgbPaginatorIntl } from './paginator-intl.service';
import * as i0 from "@angular/core";
export type PageEvent = {
    pageIndex: number;
    previousPageIndex?: number;
    pageSize: number;
    length: number;
};
export interface NgbPaginatorDefaultOptions {
    pageSize?: number;
    pageSizeOptions?: number[];
    hidePageSize?: boolean;
    showFirstLastButtons?: boolean;
}
export declare const NGB_PAGINATOR_DEFAULT_OPTIONS: InjectionToken<NgbPaginatorDefaultOptions>;
/** @docs-private */
declare const _NgbPaginatorMixinBase: (new (...args: any[]) => HasInitialized) & {
    new (): {};
};
export declare class NgbPaginator extends _NgbPaginatorMixinBase implements OnInit, OnDestroy, HasInitialized {
    _intl: NgbPaginatorIntl;
    private _changeDetectorRef;
    private _initialized;
    private _intlChanges;
    set pageIndex(value: number);
    get pageIndex(): number;
    private _pageIndex;
    set length(value: number);
    get length(): number;
    private _length;
    /** Number of items to display on a page. By default, set to 10. */
    set pageSize(value: number);
    get pageSize(): number;
    private _pageSize;
    /** The set of provided page size options to display to the user. */
    set pageSizeOptions(value: number[] | readonly number[]);
    get pageSizeOptions(): number[];
    private _pageSizeOptions;
    hidePageSize: boolean;
    showFirstLastButtons: boolean;
    disabled: boolean;
    /**
     * The paginator display size.
     *
     * Bootstrap currently supports small and large sizes.
     */
    size?: 'sm' | 'lg' | null;
    readonly page: EventEmitter<PageEvent>;
    _displayedPageSizeOptions: number[];
    constructor(_intl: NgbPaginatorIntl, _changeDetectorRef: ChangeDetectorRef, defaults?: NgbPaginatorDefaultOptions);
    ngOnInit(): void;
    ngOnDestroy(): void;
    nextPage(): void;
    previousPage(): void;
    firstPage(): void;
    lastPage(): void;
    hasPreviousPage(): boolean;
    hasNextPage(): boolean;
    getNumberOfPages(): number;
    _changePageSize(pageSize: number): void;
    _nextButtonsDisabled(): boolean;
    _previousButtonsDisabled(): boolean;
    private _updateDisplayedPageSizeOptions;
    private _emitPageEvent;
    static ɵfac: i0.ɵɵFactoryDeclaration<NgbPaginator, [null, null, { optional: true; }]>;
    static ɵcmp: i0.ɵɵComponentDeclaration<NgbPaginator, "ngb-paginator", ["ngbPaginator"], { "pageIndex": { "alias": "pageIndex"; "required": false; }; "length": { "alias": "length"; "required": false; }; "pageSize": { "alias": "pageSize"; "required": false; }; "pageSizeOptions": { "alias": "pageSizeOptions"; "required": false; }; "hidePageSize": { "alias": "hidePageSize"; "required": false; }; "showFirstLastButtons": { "alias": "showFirstLastButtons"; "required": false; }; "disabled": { "alias": "disabled"; "required": false; }; "size": { "alias": "size"; "required": false; }; }, { "page": "page"; }, never, never, false, never>;
    static ngAcceptInputType_pageIndex: unknown;
    static ngAcceptInputType_length: unknown;
    static ngAcceptInputType_pageSize: unknown;
    static ngAcceptInputType_hidePageSize: unknown;
    static ngAcceptInputType_showFirstLastButtons: unknown;
    static ngAcceptInputType_disabled: unknown;
}
export {};
//# sourceMappingURL=paginator.d.ts.map